---Like DoParam but for vehicles
---@param vehicle string Name of the vehicle script
---@param param string The parameter(s) to apply to this script
---@param module string Optional: the module of the vehicle
---@see Item#DoParam
---@see VehicleScript#Load
local DoVehicleParam = function(vehicle, param, module)
    module = module or "Base"
    local vehicleScript = ScriptManager.instance:getVehicle(module .. "." .. vehicle)
    if not vehicleScript then
        return
    end
    vehicleScript:Load(vehicle, "{" .. param .. "}")
end

---Utility to change the armor of a vehicle
---@param vehicle string Name of the vehicle script
---@param armor string Name of a armor template
---@see DoVehicleParam
local PatchArmor = function(vehicle, armor, module)
    module = module or "Base"
    DoVehicleParam(vehicle, "template! = " .. armor .. ",")
    DoVehicleParam(vehicle, "template! = ATA2AirScoopHoodFix,")
end

local AddArmor = function(vehicle, armor, module)
    module = module or "Base"
    DoVehicleParam(vehicle, "template! = " .. armor .. ",")
end

-- Apply armor patches for vanilla vehicles
PatchArmor("CarLights", "PU_armor_Normal_vve_animated")
PatchArmor("CarLightsPolice", "PU_armor_Normal_vve_animated")
PatchArmor("CarNormal", "PU_armor_Normal_vve_animated")
PatchArmor("SmallCar", "PU_armor_Small_vve_animated")
PatchArmor("PickUpVanLights", "PU_Armor_Pickup2DVan_vve_animated")
PatchArmor("PickUpVanLightsPolice", "PU_Armor_Pickup4D_vve_animated")
PatchArmor("PickUpVanLightsFire", "PU_Armor_Pickup4D_vve_animated")
PatchArmor("PickUpVan", "PU_Armor_Pickup4D_vve_animated")
PatchArmor("PickUpTruckLights", "PU_Armor_Pickup2DTruck_vve_animated")
PatchArmor("PickUpTruckLightsFire", "PU_Armor_Pickup2DTruck_vve_animated")
PatchArmor("PickUpTruck", "PU_Armor_Pickup2DTruck_vve_animated")
PatchArmor("VanAmbulance", "PU_armor_Van_vve_animated")
PatchArmor("CarTaxi", "PU_armor_Normal_vve_animated")
PatchArmor("CarTaxi2", "PU_armor_Normal_vve_animated")
PatchArmor("CarStationWagon", "PU_armor_SWagon_vve_animated")
PatchArmor("CarStationWagon2", "PU_armor_SWagon_vve_animated")
PatchArmor("ModernCar", "PU_armor_Modern_vve_animated")
PatchArmor("ModernCar02", "PU_armor_Modern02_vve_animated")
PatchArmor("CarLuxury", "PU_Armor_LuxuryCar_vve_animated")
PatchArmor("SmallCar02", "PU_Armor_Small02_vve_animated")
PatchArmor("SUV", "PU_armor_SUV_vve_animated")
PatchArmor("OffRoad", "PU_armor_Offroad_vve_animated")
PatchArmor("PickUpVanMccoy", "PU_Armor_Pickup2DVan_vve_animated")
PatchArmor("PickUpTruckMccoy", "PU_Armor_Pickup2DTruck_vve_animated")
PatchArmor("StepVan", "PU_armor_StepVan_vve_animated")
PatchArmor("StepVan_Heralds", "PU_armor_StepVan_vve_animated")
PatchArmor("StepVanMail", "PU_armor_StepVan_vve_animated")
PatchArmor("StepVan_Scarlet", "PU_armor_StepVan_vve_animated")
PatchArmor("VanSeats", "PU_armor_VanSeats_vve_animated")
PatchArmor("Van", "PU_armor_Van_vve_animated")
PatchArmor("Van_KnoxDisti", "PU_armor_Van_vve_animated")
PatchArmor("Van_Transit", "PU_armor_Van_vve_animated")
PatchArmor("VanSpiffo", "PU_armor_Van_vve_animated")
PatchArmor("VanSpecial", "PU_armor_Van_vve_animated")
PatchArmor("Van_MassGenFac", "PU_armor_Van_vve_animated")
PatchArmor("Van_LectroMax", "PU_armor_Van_vve_animated")
PatchArmor("VanRadio", "PU_armor_Van_vve_animated")
PatchArmor("VanRadio_3N", "PU_armor_Van_vve_animated")
PatchArmor("SportsCar", "PU_Armor_Sport_vve_animated")

-- Add armor for StepVanMailupz (specific to VVehicleEnhancer)
AddArmor("StepVanMailupz", "SVU_Armor_StepVan")
PatchArmor("StepVanMailupz", "PU_armor_StepVan_vve_animated")
