﻿#version 110

varying vec3 vertColour; 
varying vec3 vertNormal;
varying vec2 texCoords;
varying vec2 texCoords1;
varying vec4 positionEye;

uniform sampler2D Texture;
uniform vec4 TexturePainColor;
uniform sampler2D TextureRust;
uniform float TextureRustA;
uniform sampler2D TextureMask;
uniform sampler2D TextureLights; 

uniform vec3 TintColour;

uniform vec3 AmbientColour;
uniform vec3 Light0Direction;
uniform vec3 Light0Colour;
uniform vec3 Light1Direction;
uniform vec3 Light1Colour;
uniform vec3 Light2Direction;
uniform vec3 Light2Colour;


#include "util/math"
#include "util/SphereMap"
#include "util/dommat4"

void main()
{
	vec3 normal = normalize(vertNormal);
	vec4 tex = texture2D(Texture, texCoords);
	
	vec3 col = tex.xyz;
	float dotprod;
	float pixelVal = (col.x + col.y + col.z) / 3.0;
	
	vec4 texColorRust = texture2D(TextureRust, texCoords);
	vec3 lighting = AmbientColour;
	dotprod = max(dot(normal, normalize(Light0Direction)), 0.0);
	quantise(dotprod, 3.0);
	lighting += Light0Colour * dotprod;

	dotprod = max(dot(normal, normalize(Light1Direction)), 0.0);
	quantise(dotprod, 3.0);
	lighting += Light1Colour * dotprod;

	dotprod = max(dot(normal, normalize(Light2Direction)), 0.0);
	quantise(dotprod, 3.0);
	lighting += Light2Colour * dotprod;


    vec3 TintColourNew = desaturate(TintColour, 0.3);
	lighting.x = clamp(lighting.x, 0.0, 1.0);
	lighting.y = clamp(lighting.y, 0.0, 1.0);
	lighting.z = clamp(lighting.z, 0.0, 1.0);

	
	
	col = col*lighting*TintColourNew;
    vec3 fragHSV = rgb2hsv(col.rgb).xyz;
    fragHSV.x = TexturePainColor.x;
	fragHSV.y = clamp(fragHSV.y + TexturePainColor.y - 0.5, 0.0, 0.9999);
    fragHSV.z = clamp(fragHSV.z + TexturePainColor.z - 0.5, 0.0, 0.9999);
    fragHSV.xyz = mod(fragHSV.xyz, 1.0);
	col = mix(col, hsv2rgb(fragHSV), 1.0-tex.a);

	col = mix(col, texColorRust.xyz*lighting*TintColourNew, texColorRust.a*TextureRustA);
	
	gl_FragColor = vec4(col ,TexturePainColor.a);
}
